@@ -254,7 +254,7 @@ gimasterdark(cpl_parameterlist* config, cpl_frameset* set)
 
     GiStackingConfig* stack_config = NULL;
 
-    GiRecipeInfo info = {(cxchar*)_id, 1, NULL};
+    GiRecipeInfo info = {(cxchar*)_id, 1, NULL, config};
 
     GiGroupInfo groups[] = {
         {GIFRAME_DARK, CPL_FRAME_GROUP_RAW},
